diff --git a/core/modules/system/css/system.admin.css b/core/modules/system/css/system.admin.css
index 2577c724b1643da768345df26b25a4da8f6fe1fe..36c3f17c2dcd7c00cf42977101e9c6aad75f41f3 100644
--- a/core/modules/system/css/system.admin.css
+++ b/core/modules/system/css/system.admin.css
@@ -255,6 +255,10 @@ small .admin-link:after {
 .theme-info__description {
   margin-top: 0;
 }
+.theme-link--non-stable {
+  padding-left: 18px;
+  background: url(../../../misc/icons/e29700/warning.svg) 0 50% no-repeat; /* LTR */
+}
 .system-themes-list {
   margin-bottom: 20px;
 }
diff --git a/core/modules/system/tests/src/Functional/System/ThemeTest.php b/core/modules/system/tests/src/Functional/System/ThemeTest.php
index 6859bf697ecd2bad9a386667ef06e2361a55f1e1..7765a2b93e60436953a43195bfa0cfe0b682e498 100644
--- a/core/modules/system/tests/src/Functional/System/ThemeTest.php
+++ b/core/modules/system/tests/src/Functional/System/ThemeTest.php
@@ -288,6 +288,15 @@ public function testAdministrationTheme() {
     $this->drupalGet('admin/appearance');
     $this->submitForm($edit, 'Save configuration');
 
+    // Check the display of non stable themes.
+    $themes = \Drupal::service('theme_handler')->rebuildThemeData();
+    $experimental_version = $themes['experimental_theme_test']->info['version'];
+    $deprecated_version = $themes['deprecated_theme_test']->info['version'];
+    $this->drupalGet('admin/appearance');
+    $this->assertSession()->pageTextContains('Experimental test ' . $experimental_version . ' (experimental theme)');
+    $this->assertSession()->pageTextContains('Test deprecated theme ' . $deprecated_version . ' (Deprecated)');
+    $this->assertSession()->elementExists('xpath', "//a[contains(@href, 'http://example.com/deprecated_theme')]");
+
     // Check that the administration theme is used on an administration page.
     $this->drupalGet('admin/config');
     $this->assertSession()->responseContains('core/themes/seven');
diff --git a/core/modules/system/src/Controller/SystemController.php b/core/modules/system/src/Controller/SystemController.php
index 83b2bcce57943cbc93412b4f2e3dc08bbc6a2f6b..4d30102d06bb791a74fbc2fc309bcc3f862ba388 100644
--- a/core/modules/system/src/Controller/SystemController.php
+++ b/core/modules/system/src/Controller/SystemController.php
@@ -4,11 +4,13 @@
 
 use Drupal\Core\Cache\CacheableMetadata;
 use Drupal\Core\Controller\ControllerBase;
+use Drupal\Core\Extension\ExtensionLifecycle;
 use Drupal\Core\Extension\ModuleDependencyMessageTrait;
 use Drupal\Core\Extension\ModuleExtensionList;
 use Drupal\Core\Extension\ThemeExtensionList;
 use Drupal\Core\Extension\ThemeHandlerInterface;
 use Drupal\Core\Form\FormBuilderInterface;
+use Drupal\Core\Link;
 use Drupal\Core\Menu\MenuLinkTreeInterface;
 use Drupal\Core\Menu\MenuTreeParameters;
 use Drupal\Core\Theme\ThemeAccessCheck;
@@ -347,8 +349,7 @@ public function themesPage() {
         }
       }
 
       // Add notes to default theme, administration theme and experimental
       // themes.
       $theme->notes = [];
       if ($theme->is_default) {
         $theme->notes[] = $this->t('default theme');
@@ -356,7 +357,22 @@ public function themesPage() {
       if ($theme->is_admin) {
         $theme->notes[] = $this->t('administration theme');
       }
-      if ($theme->isExperimental()) {
+      $lifecycle = $theme->info[ExtensionLifecycle::LIFECYCLE_IDENTIFIER];
+      if (!empty($theme->info[ExtensionLifecycle::LIFECYCLE_LINK_IDENTIFIER])) {
+        $theme->notes[] = Link::fromTextAndUrl($this->t('@lifecycle', ['@lifecycle' => ucfirst($lifecycle)]),
+          Url::fromUri($theme->info[ExtensionLifecycle::LIFECYCLE_LINK_IDENTIFIER], [
+            'attributes' =>
+              [
+                'class' => 'theme-link--non-stable',
+                'aria-label' => $this->t('View information on the @lifecycle status of the theme @theme', [
+                  '@lifecycle' => ucfirst($lifecycle),
+                  '@theme' => $theme->info['name'],
+                ]),
+              ],
+          ])
+        )->toString();
+      }
+      if ($theme->isExperimental() && empty($theme->info[ExtensionLifecycle::LIFECYCLE_LINK_IDENTIFIER])) {
         $theme->notes[] = $this->t('experimental theme');
       }
 
@@ -347,8 +349,7 @@ public function themesPage() {
       }
 
-      // Add notes to default theme, administration theme and experimental
-      // themes.
+      // Add notes to default theme, administration theme and non-stable themes.
       $theme->notes = [];
       if ($theme->is_default) {